@@ -1,4 +1,4 @@
-;;; mime-parse.el --- MIME message parser
+;;; mime-parse.el --- MIME message parser  -*- lexical-binding: t -*-
 
 ;; Copyright (C) 1994,95,96,97,98,99,2001 Free Software Foundation, Inc.
 
@@ -25,13 +25,13 @@
 
 ;;; Code:
 
-(require 'custom)
 (require 'pccl)
 (require 'broken)
 
-(require 'mime-def)
 (require 'luna)
+(require 'mime-def)
 (require 'std11)
+(require 'mime)
 
 (autoload 'mime-entity-body-buffer "mime")
 (autoload 'mime-entity-body-start-point "mime")
@@ -59,8 +59,7 @@
 			  (write-read-repeat r0)
 			  ((r2 = 1)
 			   (write "(mime-token . \"")
-			   (write-read-repeat r0)))
-		  ))
+			   (write-read-repeat r0)))))
 	   (ts  `((if (r2 == 1) ((write "\")") (r2 = 0)))
 		  (write "(tspecials . \"")
 		  ,wrt
@@ -75,8 +74,7 @@
 			   (r2 = 2)
 			   (read r0)
 			   (repeat))
-			  ((read r0) (repeat)))
-		  ))
+			  ((read r0) (repeat)))))
 	   (err `((branch r2
 			  ((write "(error . \""))
 			  ((write "\")")
@@ -155,10 +153,7 @@
 			 (write ") . t)")
 			 (write "))")
 			 (write "\")))")
-			 (write "\")) . t)"))
-		 ))
-	))))
-)
+			 (write "\")) . t)")))))))))
 
 (defcustom mime-ccl-lexical-analyzer
   (static-unless (or (broken-p 'ccl-usable)
@@ -167,7 +162,8 @@
   "Specify CCL-program symbol for `mime-lexical-analyze'.
 When nil, do not use CCL.
 See docstring of `std11-ccl-lexical-analyzer' for details of CCL-program.
-If you modify `mime-lexical-analyzer', set this variable to nil or prepare corresponding CCL-program."
+If you modify `mime-lexical-analyzer', set this variable to nil
+or prepare corresponding CCL-program."
   :group 'mime
   :type '(choice symbol (const :tag "Do not use CCL." nil)))
 
@@ -257,7 +253,7 @@ be the result."
                                  (concat mime-attribute-char-regexp "+")))
                (goto-char (match-end 0)))
              (not (eobp)))
-      (insert (prog1 (format "%%%02X" (char-int (char-after)))
+      (insert (prog1 (format "%%%02X" (following-char))
                 (delete-region (point)(1+ (point))))))
     (buffer-string)))
 
@@ -372,7 +368,8 @@ property of the decoded-value."
 
 ;;; for compatibility with flim-1_13-rfc2231 API.
 (defalias 'mime-parse-parameters-from-list 'mime-decode-parameters)
-(make-obsolete 'mime-parse-parameters-from-list 'mime-decode-parameters)
+(make-obsolete 'mime-parse-parameters-from-list
+	       'mime-decode-parameters "28 Feb 2001")
 
 
 ;;; @ parameter value encoder
@@ -402,14 +399,14 @@ return value is just a string."
 	  (while (> (point-max) limit)
 	    (goto-char (- limit 3))		; (length "%XX") => 3
 	    (cond
-	     ((eq (char-after) ?%)
+	     ((eq (following-char) ?%)
 	      (forward-char 3))
 	     ((progn
 		(forward-char)
-		(eq (char-after) ?%)))
+		(eq (following-char) ?%)))
 	     ((progn
 		(forward-char)
-		(eq (char-after) ?%)))
+		(eq (following-char) ?%)))
 	     (t
 	      (forward-char)))
 	    (setq result (cons (prog1 (buffer-substring (point-min)(point))
@@ -442,8 +439,7 @@ return value is just a string."
 		  (if language (symbol-name language) "")
 		  ?')
 	  (while (re-search-forward mime-non-attribute-char-regexp nil t)
-	    (insert (prog1 (format "%%%02X" (char-int
-					     (char-after (1- (point)))))
+	    (insert (prog1 (format "%%%02X" (preceding-char))
 		      (delete-region (1- (point))(point)))))
 	  (mime-divide-extended-parameter name (buffer-string)))))))
 
@@ -467,7 +463,7 @@ just a string is returned."
 	  (while (> (point-max) limit)
 	    (goto-char (point-min))
 	    (while (< (point) limit)
-	      (when (eq (char-after) ?\\)
+	      (when (eq (following-char) ?\\)
 		(forward-char))
 	      (forward-char))
 	    (setq result (cons (concat "\""
@@ -495,7 +491,7 @@ return value is just a string."
     (insert value)
     (goto-char (point-min))
     (while (not (eobp))
-      (when (memq (char-after) '(?\\ ?\"))
+      (when (memq (following-char) '(?\\ ?\"))
 	(insert ?\\))
       (forward-char 1))
     (mime-divide-regular-parameter name (buffer-string))))
@@ -558,6 +554,9 @@ Return value is an alist of MIME parameter values."
 		    encoded (cdr encoded))))))))
     (nreverse result)))
 
+(provide 'mime-parse)
+(require 'eword-encode)
+
 (defun mime-encode-parameters-broken-mime (params)
   "Encode PARAMS plist compatibly with Outlook.
 Return value is an alist of MIME parameter values."
@@ -630,8 +629,7 @@ Return value is a mime-content-type object.
 If Content-Type field is not found, return nil."
   (let ((field-body (std11-field-body "Content-Type")))
     (if field-body
-	(mime-parse-Content-Type field-body)
-      )))
+	(mime-parse-Content-Type field-body))))
 
 
 ;;; @@ Content-Disposition
@@ -657,8 +655,7 @@ Return value is a mime-content-disposition object.
 If Content-Disposition field is not found, return nil."
   (let ((field-body (std11-field-body "Content-Disposition")))
     (if field-body
-	(mime-parse-Content-Disposition field-body)
-      )))
+	(mime-parse-Content-Disposition field-body))))
 
 
 ;;; @@ Content-Transfer-Encoding
@@ -681,8 +678,7 @@ Return value is a string.
 If Content-Transfer-Encoding field is not found, return nil."
   (let ((field-body (std11-field-body "Content-Transfer-Encoding")))
     (if field-body
-	(mime-parse-Content-Transfer-Encoding field-body)
-      )))
+	(mime-parse-Content-Transfer-Encoding field-body))))
 
 
 ;;; @@ Content-ID / Message-ID
@@ -810,8 +806,7 @@ If Content-Transfer-Encoding field is not found, return nil."
     (save-restriction
       (narrow-to-region header-start header-end)
       (setq content-type (or (mime-read-Content-Type)
-			     default-ctl))
-      )
+			     default-ctl)))
     (luna-make-entity representation-type
 		      :location (current-buffer)
 		      :content-type content-type
@@ -821,8 +816,7 @@ If Content-Transfer-Encoding field is not found, return nil."
 		      :header-start header-start
 		      :header-end header-end
 		      :body-start body-start
-		      :body-end body-end)
-    ))
+		      :body-end body-end)))
 
 
 ;;; @ for buffer
